@@ -34,37 +34,26 @@ class PiecewiseBasis(BasePulse):
 
         :param dict pulse_dictionary: Should contain the basis_dict under the key "basis" and should contain the number of bins and time spacing under "n_bins" and "dt"
         """
-        # basis_dict = pulse_dictionary["basis"]
-        # Constructor of the parent class, i.e. Chopped Basis
         self.control_parameters_number = pulse_dictionary["bins_number"]
         super().__init__(map_index=map_index, rng=rng, **pulse_dictionary)
-        # self.control_parameters_number = 1
-        # super().__init__(**kwargs)
-        # basis_attribute = dynamic_import(attribute=basis.setdefault("basis_attribute", None),
-        #                                     module_name=basis.setdefault("basis_module", None),
-        #                                     class_name=basis.setdefault("basis_class", None))
-
         #################
         # Basis dependent settings
         #################
+        self.offset_coefficients = np.zeros((self.control_parameters_number, ))
+        self.scale_coefficients = self.amplitude_variation * np.ones((self.control_parameters_number, ))
 
-    def setdefault(a, b, c):
+    # def setdefault(a, b, c):
+    #     class Skipper:
+    #         def __init__(self):
+    #             self.last_index = 0
+    #
+    #     return lambda x, y: Skipper()
 
-        class Skipper:
-
-            def __init__(self):
-                self.last_index = 0
-
-        return lambda x, y: Skipper()
-
-    # TODO check if this function is really called by GRAPE
     def _get_shaped_pulse(self) -> np.array:
         """Definition of the pulse parametrization. It is called at every function evaluation to build the pulse"""
         #################
         # Standard Basis Settings: amplitude limits, amplitude variation for the simplex,
         # distribution of super parameters, etc ...
         ################
-        pulse = self.pulse_amplitudes
-        # in the case of a piecewise basis the pulse is defined by the amplitudes
-
+        pulse = self.optimized_control_parameters
         return pulse
